==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/Sba73a8567cc242336c1f32778fecac2c.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "Sfffef868da20c3f5623f11331ac9a581.h"

#include "S76eaa083f88fdd66f6f3f7ac1cd91f27.h"

#include "Sfd40bde7becba15faa6c7faab35e20f0.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S57eed6fb2a8ce5b9f949ceebffa654b5.h"
  void Se53020f5f58854e13d948924ee8cb076(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179) 
{ S749d2b576e15d77f0d14f186077e9ace Sc21a78c5557260037e428b49d624b398; Sc21a78c5557260037e428b49d624b398 
= S749d2b576e15d77f0d14f186077e9ace() + "\n\
log_analysis_info_directory \"\" \n\
statistics_server_directory \"\" \n\
statistics_server_url \"\" \n\
security_mode \"browse_and_modify\" \n\
configuration_mode \"\" \n\
automatically_update_when_older_than 86400 \n\
safe_updates true \n\
max_resident_configurations 0 \n\
maximum_number_of_threads 4 \n\
european_dates false \n\
\n\
server_root '' \n\
server_hostname '' \n\
database_directory \"\" \n\
web_server false \n\
web_server_port 8987 \n\
trusted_hosts \"\" \n\
show_full_operating_system_details_in_errors true \n\
show_logo_in_administrative_header true \n\
authentication_command_line \"\"\n\
administrative_bar_color 247 201 131\n\
master_process_id \"\" \n\
cgi_directory \"/cgi-bin/\" \n\
share_bar_box_images true \n\
entry_name default \n\
number_thousands_divider ,\n\
language_module_pathname \"English\" \n\
\n\
expanded_edit_limits_items \"\" \n\
expanded_session_paths \"\" \n\
\n\
generate_html_to_directory \"\" \n\
generate_html_click_depth 0 \n\
page_hits_link_cutoff 1 \n\
\n\
require_password f \n\
config_view_statistics_password \"\" \n\
command_line_password \"\" \n\
\n\
default_permissions 644 \n\
database_file_permissions 644 \n\
database_directory_permissions 1755 \n\
configuration_file_permissions 644 \n\
configuration_directory_permissions 1755 \n\
temporary_config_file_permissions 700 \n\
default_configuration_file_permissions 644 \n\
password_file_permissions 600 \n\
image_file_permissions 666 \n\
image_directory_permissions 755 \n\
server_directory_permissions 755 \n\
log_analysis_info_directory_permissions 1755 \n\
\n\
help f \n\
help_on \"\" \n\
show_configuration_status \"\" \n\
\n\
interview \"\" \n\
interview_page \"\" \n\
\n\
print_subitems false path \n\
\n\
read_from_config_file \"\" \n\
write_to_config_file \"\" \n\
config_name \"\" \n\
\n\
" 
 "\
log_source_url \"\"\n\
use_regular_expressions_for_log_source false \n\
process_log_source_subdirectories false \n\
server_side_include_mode false \n\
generate_image false \n\
log_to_write_pathname \"\" \n\
write_log_entry_for_page \"\" \n\
write_accepted_entries_to_log \"\" \n\
" 
 "\
\n\
count_hits false \n\
count_page_views true \n\
count_bandwidth false \n\
count_visitors false \n\
track_session_information false \n\
tally_hits_on_directories_only true \n\
omit_ip_numbers_from_host_hierarchy false \n\
apparent_statistics_root nofilters\n\
session_timeout 1800\n\
max_session_duration 7200\n\
\n\
hash_table_starting_size 4096 \n\
hash_table_expansion_factor 2 \n\
hash_table_surplus_factor 1 \n\
num_database_segments 10 \n\
cross_reference_groups xref_groups_end \n\
database_access_chunk_size 1024 \n\
database_write_buffer_size 10M \n\
maximum_visitor_memory_usage 5M \n\
maximum_session_memory_usage 10M \n\
database_disk_write_buffer_size 200M \n\
database_read_cache_size 5000 \n\
database_freshness 0 \n\
prompt_before_erasing_database true \n\
force_database_reload false \n\
force_database_steal false \n\
\n\
get_hits false \n\
\n\
look_up_ip_numbers false \n\
dns_timeout 10 \n\
dns_server \"\" \n\
secondary_dns_server \"\" \n\
use_tcp_for_dns false \n\
maximum_simultaneous_dns_lookups 1000\n\
log_entry_pool_size 1000\n\
temporary_files_lifespan 3600\n\
never_look_up_ip_numbers false \n\
only_look_up_log_ip_numbers true \n\
look_up_ip_numbers_before_filtering false \n\
ip_numbers_cache_file IPNumberCache \n\
\n\
smtp_server_hostname \"\"\n\
return_address user@domain \n\
actions_email_address \"\" \n\
view_email_address user@domain \n\
view_to_send_by_email Overview \n\
view_email_subject \"{CONFIG_NAME}: {VIEW_TO_SEND_BY_EMAIL}\"\n\
running_statistics_url \"\"\n\
logout_url \"\"\n\
\n\
" 
 "\
place_view_menu_at_top true \n\
\n\
active_category logsource\n\
active_statistics_view calendar\n\
\n\
" 
 "\
page_header '' \n\
page_footer '' \n\
page_header_file '' \n\
page_footer_file '' \n\
page_frame_command '' \n\
preprocess_headers_and_footers false \n\
\n\
view_info standard view_end \n\
\n\
hidden_views_url ''\n\
\n\
bar_unit_image defbbaru.gif \n\
left_bar_cap_image defbbarl.gif \n\
right_bar_cap_image defbbarr.gif \n\
statistics_page_background_color 255 255 255 \n\
view_sidebar_background_color 255 255 255 \n\
html_table_bar_color 102 102 255 \n\
page_views_table_bar_color 204 51 200 \n\
bandwidth_table_bar_color 102 255 102 \n\
visitors_table_bar_color 255 102 102 \n\
sessions_information_color 52 204 204 \n\
date_line_graph_width 400 \n\
date_line_graph_height 130 \n\
date_bar_graph_height 50 \n\
date_line_graph_equation_line_color 204 0 0 \n\
date_line_graph_background_color 255 255 255 \n\
date_line_graph_outline_color 204 204 204 \n\
date_line_graph_text_color 0 0 0 \n\
ignore_last_points_for_equation 1 \n\
date_offset 0 \n\
\n\
" 
 "\
max_pie_chart_slices 20 \n\
pie_chart_slice_minimum_degrees 1 \n\
pie_chart_slice_color  1   102 102 255 \n\
pie_chart_slice_color  2   153   0 153 \n\
pie_chart_slice_color  3   255 102  51 \n\
pie_chart_slice_color  4    51 153  51 \n\
pie_chart_slice_color  5   255   0 153 \n\
pie_chart_slice_color  6   153 153 255 \n\
pie_chart_slice_color  7    51 255  51 \n\
pie_chart_slice_color  8   255  51 255 \n\
pie_chart_slice_color  9    51 255 255 \n\
pie_chart_slice_color  10  153  51  51 \n\
pie_chart_slice_color  11   51  51 153 \n\
pie_chart_slice_color  12  255 255 204 \n\
pie_chart_slice_color  13  153  51 255 \n\
pie_chart_slice_color  14  153 153  51 \n\
pie_chart_slice_color  15  204 153 153 \n\
pie_chart_slice_color  16  255 153  51 \n\
pie_chart_slice_color  17    0 101 101 \n\
pie_chart_slice_color  18  204 255 153 \n\
pie_chart_slice_color  19  204 101 101 \n\
pie_chart_slice_color  20   51 204 204 \n\
use_tables_for_legend_squares true \n\
use_tables_for_table_bars false \n\
make_graph_bars_clickable true \n\
stretch_bar_unit true \n\
" 
 "\
pie_chart_width 150 \n\
pie_chart_height 75 \n\
pie_chart_depth 15 \n\
\n\
internal_scratch_option \"\" \n\
\n\
show_full_instructions false \n\
show_hide_menus_affect_all_views true \n\
show_statistics_credit_in_information_banner true \n\
show_only_remote_user_configurations false \n\
administrative_remote_user administrator \n\
generate_path_reference_icons true \n\
use_3d_graphs true \n\
light_direction_vector -2 -3 4 \n\
compact_tables false \n\
\n\
expire_database_data \"\"\n\
\n\
skip_log_entries 0 \n\
skip_first_log_entries 0 \n\
skip_processed_filenames_on_update false \n\
allow_empty_log_source false \n\
reject_entries_before '01/Jan/1970 00:00:00' \n\
reject_entries_after '01/Jan/2030 00:00:00' \n\
filter_before_skipping false \n\
" 
 "\
calendar_month_columns 4 \n\
first_day_of_week 1 \n\
max_table_bar_length 100 \n\
table_bar_height 12 \n\
max_table_item_length 40 \n\
max_table_item_rows 4 \n\
sample_time_units 5 \n\
expand_paths_greater_than 50 \n\
\n\
optimize false \n\
optimize_items false \n\
\n\
verbose egb \n\
all_output_to_master_config false \n\
use_progress_bar true \n\
show_advanced_progress_info false \n\
progress_page_interval 5 \n\
use_multithreading true \n\
max_cpu_usage_percent 100 \n\
multithread_log_reading false \n\
log_parsing_threads 1 \n\
log_filtering_threads 1 \n\
database_feeding_threads 1 \n\
database_consolidating_threads 1 \n\
\n\
log_block_size 65536 \n\
hide_in_user_menu false \n\
show_docs_links_in_stats true \n\
generate_bookmark false \n\
\n\
log_data_type http_access \n\
log_file_format \"\" \n\
log_file_format_regular_expression \"\"\n\
log_format_autodetect_regular_expression \"\"\n\
log_format_description_string \"\"\n\
apache_log_format_description_string \"\"\n\
detail_level \"\"\n\
global_date_regular_expression \"\"\n\
global_date_filename_regular_expression \"\"\n\
default_log_date_year 2002\n\
\n\
log_field_separator \"\" \n\
#log_field_info standard field_end \n\
#database_field_info standard field_end \n\
\n\
log_date_format mm/dd/yy \n\
log_time_format hh:mm:ss \n\
treat_brackets_as_quotes false \n\
allow_newlines_inside_quotes false \n\
parse_only_with_filters false \n\
ignore_format_lines false \n\
common_log_format false \n\
\n\
#log_filters standard filter_end \n\
#log_parsing_filters standard filter_end \n\
num_database_fields 1 \n\
filters nofilters \n\
session_information_filters nofilters \n\
page_paths_page \"\"\n\
\n\
"; 
S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Sa06479a6543b64a37b0844f4256184c5 
= true; Saf6c0c3c714d1f5ab0d299b2cbf50060(S4fc01cd28e4d32966c4811fb49f098ca(S4d682ec4eed27c53849758bc13b6e179, 
Sc21a78c5557260037e428b49d624b398, "(default config)", S05d810f1eadff00205477bc3a977236d)); S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Sa06479a6543b64a37b0844f4256184c5 
= false; }

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/Sba73a8567cc242336c1f32778fecac2c.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "Sfffef868da20c3f5623f11331ac9a581.h"

#include "S76eaa083f88fdd66f6f3f7ac1cd91f27.h"

#include "Sfd40bde7becba15faa6c7faab35e20f0.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S57eed6fb2a8ce5b9f949ceebffa654b5.h"
  void Se53020f5f58854e13d948924ee8cb076(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179) 
{ S749d2b576e15d77f0d14f186077e9ace Sc21a78c5557260037e428b49d624b398; Sc21a78c5557260037e428b49d624b398 
= S749d2b576e15d77f0d14f186077e9ace() + "\n\
log_analysis_info_directory \"\" \n\
statistics_server_directory \"\" \n\
statistics_server_url \"\" \n\
security_mode \"browse_and_modify\" \n\
configuration_mode \"\" \n\
automatically_update_when_older_than 86400 \n\
safe_updates true \n\
max_resident_configurations 0 \n\
maximum_number_of_threads 4 \n\
european_dates false \n\
\n\
server_root '' \n\
server_hostname '' \n\
database_directory \"\" \n\
web_server false \n\
web_server_port 8987 \n\
trusted_hosts \"\" \n\
show_full_operating_system_details_in_errors true \n\
show_logo_in_administrative_header true \n\
authentication_command_line \"\"\n\
administrative_bar_color 247 201 131\n\
master_process_id \"\" \n\
cgi_directory \"/cgi-bin/\" \n\
share_bar_box_images true \n\
entry_name default \n\
number_thousands_divider ,\n\
language_module_pathname \"English\" \n\
support_email_address \"\" \n\
\n\
expanded_edit_limits_items \"\" \n\
expanded_session_paths \"\" \n\
\n\
generate_html_to_directory \"\" \n\
generate_html_click_depth 0 \n\
page_hits_link_cutoff 1 \n\
\n\
require_password f \n\
config_view_statistics_password \"\" \n\
command_line_password \"\" \n\
allow_viewers_to_rebuild false \n\
\n\
default_permissions 644 \n\
database_file_permissions 644 \n\
database_directory_permissions 1755 \n\
configuration_file_permissions 644 \n\
configuration_directory_permissions 1755 \n\
temporary_config_file_permissions 700 \n\
default_configuration_file_permissions 644 \n\
password_file_permissions 600 \n\
image_file_permissions 666 \n\
image_directory_permissions 755 \n\
server_directory_permissions 755 \n\
log_analysis_info_directory_permissions 1755 \n\
\n\
help f \n\
help_on \"\" \n\
show_configuration_status \"\" \n\
\n\
interview \"\" \n\
interview_page \"\" \n\
\n\
print_subitems false path \n\
\n\
read_from_config_file \"\" \n\
write_to_config_file \"\" \n\
config_name \"\" \n\
\n\
" 
 "\
log_source_url \"\"\n\
use_regular_expressions_for_log_source false \n\
process_log_source_subdirectories false \n\
server_side_include_mode false \n\
generate_image false \n\
log_to_write_pathname \"\" \n\
write_log_entry_for_page \"\" \n\
write_accepted_entries_to_log \"\" \n\
" 
 "\
\n\
count_hits false \n\
count_page_views true \n\
count_bandwidth false \n\
count_visitors false \n\
track_session_information false \n\
tally_hits_on_directories_only true \n\
omit_ip_numbers_from_host_hierarchy false \n\
apparent_statistics_root nofilters\n\
session_timeout 1800\n\
max_session_duration 7200\n\
\n\
hash_table_starting_size 4096 \n\
hash_table_expansion_factor 2 \n\
hash_table_surplus_factor 1 \n\
num_database_segments 10 \n\
cross_reference_groups xref_groups_end \n\
database_access_chunk_size 1024 \n\
database_write_buffer_size 10M \n\
maximum_visitor_memory_usage 5M \n\
maximum_session_memory_usage 10M \n\
database_disk_write_buffer_size 200M \n\
database_read_cache_size 5000 \n\
database_freshness 0 \n\
prompt_before_erasing_database true \n\
force_database_reload false \n\
force_database_steal false \n\
\n\
get_hits false \n\
\n\
look_up_ip_numbers false \n\
dns_timeout 10 \n\
dns_server \"\" \n\
secondary_dns_server \"\" \n\
use_tcp_for_dns false \n\
maximum_simultaneous_dns_lookups 1000\n\
log_entry_pool_size 1000\n\
temporary_files_lifespan 3600\n\
never_look_up_ip_numbers false \n\
only_look_up_log_ip_numbers true \n\
look_up_ip_numbers_before_filtering false \n\
ip_numbers_cache_file IPNumberCache \n\
\n\
smtp_server_hostname \"\"\n\
return_address user@domain \n\
actions_email_address \"\" \n\
view_email_address user@domain \n\
view_to_send_by_email Overview \n\
view_email_subject \"{CONFIG_NAME}: {VIEW_TO_SEND_BY_EMAIL}\"\n\
running_statistics_url \"\"\n\
logout_url \"\"\n\
\n\
" 
 "\
place_view_menu_at_top true \n\
\n\
active_category logsource\n\
active_statistics_view calendar\n\
\n\
" 
 "\
page_header '' \n\
page_footer '' \n\
page_header_file '' \n\
page_footer_file '' \n\
page_frame_command '' \n\
sub_view_header '' \n\
sub_view_footer '' \n\
preprocess_headers_and_footers false \n\
\n\
view_info standard view_end \n\
\n\
hidden_views_url ''\n\
\n\
bar_unit_image defbbaru.gif \n\
left_bar_cap_image defbbarl.gif \n\
right_bar_cap_image defbbarr.gif \n\
statistics_page_background_color 255 255 255 \n\
view_sidebar_background_color 255 255 255 \n\
html_table_bar_color 102 102 255 \n\
page_views_table_bar_color 204 51 200 \n\
bandwidth_table_bar_color 102 255 102 \n\
visitors_table_bar_color 255 102 102 \n\
sessions_information_color 52 204 204 \n\
date_line_graph_width 400 \n\
date_line_graph_height 130 \n\
date_bar_graph_height 50 \n\
date_line_graph_equation_line_color 204 0 0 \n\
date_line_graph_background_color 255 255 255 \n\
date_line_graph_outline_color 204 204 204 \n\
date_line_graph_text_color 0 0 0 \n\
ignore_last_points_for_equation 1 \n\
date_offset 0 \n\
\n\
" 
 "\
max_pie_chart_slices 20 \n\
pie_chart_slice_minimum_degrees 1 \n\
pie_chart_slice_color  1   102 102 255 \n\
pie_chart_slice_color  2   153   0 153 \n\
pie_chart_slice_color  3   255 102  51 \n\
pie_chart_slice_color  4    51 153  51 \n\
pie_chart_slice_color  5   255   0 153 \n\
pie_chart_slice_color  6   153 153 255 \n\
pie_chart_slice_color  7    51 255  51 \n\
pie_chart_slice_color  8   255  51 255 \n\
pie_chart_slice_color  9    51 255 255 \n\
pie_chart_slice_color  10  153  51  51 \n\
pie_chart_slice_color  11   51  51 153 \n\
pie_chart_slice_color  12  255 255 204 \n\
pie_chart_slice_color  13  153  51 255 \n\
pie_chart_slice_color  14  153 153  51 \n\
pie_chart_slice_color  15  204 153 153 \n\
pie_chart_slice_color  16  255 153  51 \n\
pie_chart_slice_color  17    0 101 101 \n\
pie_chart_slice_color  18  204 255 153 \n\
pie_chart_slice_color  19  204 101 101 \n\
pie_chart_slice_color  20   51 204 204 \n\
use_tables_for_legend_squares true \n\
use_tables_for_table_bars false \n\
make_graph_bars_clickable true \n\
stretch_bar_unit true \n\
" 
 "\
pie_chart_width 150 \n\
pie_chart_height 75 \n\
pie_chart_depth 15 \n\
\n\
internal_scratch_option \"\" \n\
\n\
show_full_instructions false \n\
show_hide_menus_affect_all_views true \n\
show_statistics_credit_in_information_banner true \n\
show_only_remote_user_configurations false \n\
administrative_remote_user administrator \n\
generate_path_reference_icons true \n\
use_3d_graphs true \n\
light_direction_vector -2 -3 4 \n\
compact_tables false \n\
\n\
expire_database_data \"\"\n\
\n\
skip_log_entries 0 \n\
skip_first_log_entries 0 \n\
skip_processed_filenames_on_update false \n\
allow_empty_log_source false \n\
reject_entries_before '01/Jan/1970 00:00:00' \n\
reject_entries_after '01/Jan/2030 00:00:00' \n\
filter_before_skipping false \n\
" 
 "\
calendar_month_columns 4 \n\
first_day_of_week 1 \n\
max_table_bar_length 100 \n\
table_bar_height 12 \n\
max_table_item_length 40 \n\
max_table_item_rows 4 \n\
max_filter_menu_length 1000\n\
sample_time_units 5 \n\
expand_paths_greater_than 500 \n\
\n\
optimize false \n\
optimize_items false \n\
\n\
verbose egb \n\
all_output_to_master_config false \n\
use_progress_bar true \n\
show_advanced_progress_info false \n\
progress_page_interval 5 \n\
use_multithreading true \n\
max_cpu_usage_percent 100 \n\
multithread_log_reading false \n\
log_parsing_threads 1 \n\
log_filtering_threads 1 \n\
database_feeding_threads 1 \n\
database_consolidating_threads 1 \n\
\n\
log_block_size 65536 \n\
hide_in_user_menu false \n\
show_docs_links_in_stats true \n\
generate_bookmark false \n\
\n\
log_data_type http_access \n\
log_file_format \"\" \n\
log_file_format_regular_expression \"\"\n\
log_format_autodetect_regular_expression \"\"\n\
log_format_description_string \"\"\n\
apache_log_format_description_string \"\"\n\
detail_level \"\"\n\
global_date_regular_expression \"\"\n\
global_date_filename_regular_expression \"\"\n\
default_log_date_year 2003\n\
\n\
log_field_separator \"\" \n\
#log_field_info standard field_end \n\
#database_field_info standard field_end \n\
\n\
log_date_format mm/dd/yy \n\
log_time_format hh:mm:ss \n\
ignore_quotes false \n\
treat_brackets_as_quotes false \n\
allow_newlines_inside_quotes false \n\
parse_only_with_filters false \n\
collected_entry_lifespan 10000 \n\
ignore_format_lines false \n\
common_log_format false \n\
\n\
#log_filters standard filter_end \n\
#log_parsing_filters standard filter_end \n\
num_database_fields 1 \n\
filters nofilters \n\
session_information_filters nofilters \n\
extra_session_columns \"\"\n\
page_paths_page \"\"\n\
\n\
"; 
S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Sa06479a6543b64a37b0844f4256184c5 
= true; Saf6c0c3c714d1f5ab0d299b2cbf50060(S4fc01cd28e4d32966c4811fb49f098ca(S4d682ec4eed27c53849758bc13b6e179, 
Sc21a78c5557260037e428b49d624b398, "(default config)", S05d810f1eadff00205477bc3a977236d)); S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.Sa06479a6543b64a37b0844f4256184c5 
= false; }
